@@ -1,34 +1,36 @@
 ## Server.R
 ## MAIN FUNCTION
 function(input, output, session) {
-  
+
   # input data (with default)
   values <- reactiveValues(data_primary = ExampleData.DeValues$CA1,
-                           data_secondary = setNames(as.data.frame(matrix(NA_real_, nrow = 5, ncol = 2)), c("x", "y")))
-  
+                           data_secondary = setNames(as.data.frame(matrix(NA_real_, nrow = 5, ncol = 2)), c("x", "y")),
+                           data = NULL,
+                           args = NULL)
+
   ### GET DATA SETS
-  Data<- reactive({
+  observe({
 
     ### GET DATA
     data <- list(values$data_primary, values$data_secondary)
-    data <- lapply(data, function(x) { 
+    data <- lapply(data, function(x) {
       x_tmp <- x[complete.cases(x), ]
       if (nrow(x_tmp) == 0) return(NULL)
       else return(x_tmp)
     })
     data <- data[!sapply(data, is.null)]
     data <- lapply(data, function(x) setNames(x, c("Dose", "Error")))
-    
+
     ### DATA FILTER
     input$exclude
-    
+
     sub <- data
-    
+
     isolate({
       filter.prim<- input$filter.prim
       filter.sec<- input$filter.sec
     })
-    
+
     if(!is.null(filter.prim)) {
       index<- grep(paste(filter.prim, collapse = "|"), data[[1]][,1])
       sub[[1]]<- data[[1]][-index,]
@@ -37,68 +39,67 @@ function(input, output, session) {
       index<- grep(paste(filter.sec, collapse = "|"), data[[2]][,1])
       sub[[2]]<- data[[2]][-index,]
     }
-    
+
     stillSelected.prim<- filter.prim
     stillSelected.sec<- filter.sec
-    
+
     updateSelectInput(session, inputId = "filter.prim", choices = sort(data[[1]][,1]), selected = stillSelected.prim)
     if(length(data) == 2) {
       updateSelectInput(session, inputId = "filter.sec", choices = sort(data[[2]][,1]), selected = stillSelected.sec)
     }
-    data<- sub
-    
-    return(data)
+
+    values$data <- sub
   })
-  
+
   output$table_in_primary <- renderRHandsontable({
-    rhandsontable(values$data_primary, 
-                  height = 300, 
-                  colHeaders = c("Dose", "Error"), 
+    rhandsontable(values$data_primary,
+                  height = 300,
+                  colHeaders = c("Dose", "Error"),
                   rowHeaders = NULL)
   })
-  
+
   observeEvent(input$table_in_primary, {
-    
-    # Workaround for rhandsontable issue #138 
+
+    # Workaround for rhandsontable issue #138
     # https://github.com/jrowen/rhandsontable/issues/138
     # Desc.: the rownames are not updated when copying values in the table
-    # that exceed the current number of rows; hence, we have to manually 
+    # that exceed the current number of rows; hence, we have to manually
     # update the rownames before running hot_to_r(), which would crash otherwise
-    
+
     # to modify the rhandsontable we need to create a local non-reactive variable
     df_tmp <- input$table_in_primary
     row_names <-  as.list(as.character(seq_len(length(df_tmp$data))))
-    
+
     # now overwrite the erroneous entries in the list: 'rRowHeaders', 'rowHeaders'
     # and 'rDataDim'
     df_tmp$params$rRowHeaders <- row_names
     df_tmp$params$rowHeaders <- row_names
     df_tmp$params$rDataDim <- as.list(c(length(row_names),
                                         length(df_tmp$params$columns)))
-    
+
     # With the above workaround we run into the problem that the 'afterRemoveRow'
     # event checked in rhandsontable:::toR also tries to remove the surplus rowname(s)
     # For now, we can overwrite the event and handle the 'afterRemoveRow' as a usual
     # 'afterChange' event
     if (df_tmp$changes$event == "afterRemoveRow")
       df_tmp$changes$event <- "afterChange"
-    
+
     if (!is.null(hot_to_r(df_tmp)))
       values$data_primary <- hot_to_r(df_tmp)
   })
-  
+
   output$table_in_secondary <- renderRHandsontable({
-    
-    rhandsontable(values$data_secondary, 
+
+    rhandsontable(values$data_secondary,
                   height = 300,
-                  colHeaders = c("Dose", "Error"), 
+                  colHeaders = c("Dose", "Error"),
                   rowHeaders = NULL)
   })
-  
-  
+
+
   observeEvent(input$table_in_secondary, {
-    
-    # Workaround for rhandsontable issue #138 
+
+    # Workaround for rhandsontable issue #138
     # https://github.com/jrowen/rhandsontable/issues/138
     # See detailed explanation above
     df_tmp <- input$table_in_secondary
@@ -109,37 +110,37 @@ function(input, output, session) {
                                         length(df_tmp$params$columns)))
     if (df_tmp$changes$event == "afterRemoveRow")
       df_tmp$changes$event <- "afterChange"
-    
+
     if (!is.null(hot_to_r(df_tmp)))
       values$data_secondary <- hot_to_r(df_tmp)
-    
+
   })
-  
+
   # check and read in file (DATA SET 1)
   observeEvent(input$file1, {
     inFile<- input$file1
-    
-    if(is.null(inFile)) 
+
+    if(is.null(inFile))
       return(NULL) # if no file was uploaded return NULL
-    
-    values$data_primary <- fread(file = inFile$datapath, data.table = FALSE) # inFile[1] contains filepath 
+
+    values$data_primary <- fread(file = inFile$datapath, data.table = FALSE) # inFile[1] contains filepath
   })
-  
+
   # check and read in file (DATA SET 2)
   observeEvent(input$file2, {
     inFile<- input$file2
-    
-    if(is.null(inFile)) 
+
+    if(is.null(inFile))
       return(NULL) # if no file was uploaded return NULL
-    
-    values$data_secondary <- fread(file = inFile$datapath, data.table = FALSE) # inFile[1] contains filepath 
+
+    values$data_secondary <- fread(file = inFile$datapath, data.table = FALSE) # inFile[1] contains filepath
   })
-  
+
   # dynamically inject sliderInput for x-axis range
   output$xlim<- renderUI({
-    
-    data<- Data()
-    
+
+    data<- values$data
+
     if(input$logz == TRUE) {
       sd<- unlist(lapply(data, function(x) x[,2]/x[,1]))
     } else {
@@ -148,39 +149,39 @@ function(input, output, session) {
     prec<- 1/sd
     sliderInput(inputId = "xlim", sep="",
                 label = "Range x-axis",
-                min = 0, 
+                min = 0,
                 max = round(max(prec)*2, 3),
                 value = c(0, max(prec)*1.05))
   })## EndOf::renderUI()
-  
+
   # dynamically inject sliderInput for z-axis range
   output$zlim<- renderUI({
-    
-    data<- unlist(lapply(Data(), function(x) x[,1]))
-    
+
+    data<- unlist(lapply(values$data, function(x) x[,1]))
+
     min<- min(data)
     max<- max(data)
     sliderInput(inputId = "zlim",  sep="",
-                label = "Range z-axis", 
+                label = "Range z-axis",
                 min = min*0.25,
                 max = round(max*1.75, 3),
                 value = c(min*0.8, max*1.2))
   })## EndOf::renderUI()
-  
-  
+
+
   output$ylim<- renderUI({
-    ylim<- plot_AbanicoPlot(Data(), output = TRUE)$ylim
+    ylim<- plot_AbanicoPlot(values$data, output = TRUE)$ylim
     sliderInput(inputId = "ylim",  sep="",
                 label = "Range y-axis",
-                min = ylim[1]*4, 
+                min = ylim[1]*4,
                 max = round(ylim[2]*4, 3),
                 value = c(ylim[1], ylim[2]))
   })
-  
-  
+
+
   # dynamically inject sliderInput for KDE bandwidth
   output$bw<- renderUI({
-    data<- unlist(lapply(Data(), function(x) x[,1]))
+    data<- unlist(lapply(values$data, function(x) x[,1]))
     if(input$logz == TRUE) {
       data<- log(data)
       min<- 0.001
@@ -192,50 +193,27 @@ function(input, output, session) {
       max<- value*4
     }
     sliderInput(inputId = "bw",  sep="",
-                label = "KDE bandwidth", 
-                min = round(min, 3), 
+                label = "KDE bandwidth",
+                min = round(min, 3),
                 max = round(max, 3),
                 value = value)
   })## EndOf::renderUI()
-  
-  # observe({
-  #   # case: 1 data set, 2 sigma bars --> switch to custom value
-  #   if(input$addBar == TRUE && is.null(datGet2())) {
-  #     updateSelectInput(session = session, inputId = "centrality", 
-  #                       label = "Centrality",
-  #                       selected = "custom")
-  #   }
-  #   # case: 1 data set, 1 sigma bars --> return to mean centrality
-  #   if(input$addBar == FALSE && is.null(datGet2())) {
-  #     updateSelectInput(session = session, inputId = "centrality", 
-  #                       label = "Centrality",
-  #                       selected = "mean")
-  #   }
-  # })  
-  
-  
+
+
   output$centralityNumeric<- renderUI({
-    
-    data <- Data()
-    
-    numericInput(inputId = "centralityNumeric", 
-                 label = "Value", 
+
+    data <- values$data
+
+    numericInput(inputId = "centralityNumeric",
+                 label = "Value",
                  value = round(mean(data[[1]][,1]), 2),
                  step = 0.01)
   })
-  
-  # render Abanico Plot
-  output$main_plot <- renderPlot({
-    
+
+  observe({
     # refresh plot on button press
     input$refresh
-    
-    # progress bar
-    progress<- Progress$new(session, min = 0, max = 5)
-    progress$set(message = "Calculation in progress",
-                 detail = "Retrieve data")
-    on.exit(progress$close())
-    
+
     # make sure that input panels are registered on non-active tabs.
     # by default tabs are suspended and input variables are hence
     # not available
@@ -244,25 +222,10 @@ function(input, output, session) {
     outputOptions(x = output, name = "xlim", suspendWhenHidden = FALSE)
     outputOptions(x = output, name = "ylim", suspendWhenHidden = FALSE)
     outputOptions(x = output, name = "centralityNumeric", suspendWhenHidden = FALSE)
-    
-    # get data
-    data<- Data()
-    
-    # update progress bar
-    progress$set(value = 1)
-    progress$set(message = "Calculation in progress",
-                 detail = "Get values")
-    
-    # check if any summary stats are activated, else NA
-    ifelse(input$summary, summary<- input$stats, summary<- NA)
-    
+
     # if custom datapoint color get RGB code from separate input panel
-    if(input$color == "custom") {
-      color<- ifelse(input$jscol1 == "", "black", input$jscol1)
-    } else {
-      color<- input$color
-    }
-    
+    color <- ifelse(input$color == "custom", input$jscol1, input$color)
+
     if(!all(is.na(unlist(values$data_secondary)))) {
       # if custom datapoint color get RGB code from separate input panel
       if(input$color2 == "custom") {
@@ -277,103 +240,65 @@ function(input, output, session) {
     } else {
       color2<- "black" #adjustcolor("white", alpha.f = 0)
     }
-    
+
     # if custom datapoint style get char from separate input panel
     pch<- ifelse(input$pch == "custom", input$custompch, as.integer(input$pch)-1)
-    
+
     # if custom datapoint style get char from separate input panel
     pch2<- ifelse(input$pch2 == "custom", input$custompch2, as.integer(input$pch2)-1)
-    
-    # update progress bar
-    progress$set(value = 2)
-    progress$set(message = "Calculation in progress",
-                 detail = "Combine values")
-    
+
     # create numeric vector of lines
-    line<-  as.numeric(c(input$line1, input$line2,
-                         input$line3, input$line4,
-                         input$line5, input$line6,
-                         input$line7, input$line8))
-    
+    line <- sapply(1:8, function(x) input[[paste0("line", x)]])
+
     # create char vector of line colors
-    line.col<-  c(input$colline1, input$colline2,
-                  input$colline3, input$colline4,
-                  input$colline5, input$colline6,
-                  input$colline7, input$colline8)
-    
-    line.col[which(line.col=="#")] <- "#FFFFFF"
-    
+    line.col <- sapply(1:8, function(x) input[[paste0("colline", x)]])
+
     # create char vector of line labels
-    line.label<- c(input$labline1, input$labline2,
-                   input$labline3, input$labline4,
-                   input$labline5, input$labline6,
-                   input$labline7, input$labline8)
-    
+    line.label <- sapply(1:8, function(x) input[[paste0("labline", x)]])
+
     # create integer vector of line types
-    line.lty<- as.integer(c(input$linelty1, input$linelty2,
-                            input$linelty3, input$linelty4,
-                            input$linelty5, input$linelty6,
-                            input$linelty7, input$linelty8))
-    
-    # update progress bar
-    progress$set(value = 3)
-    progress$set(message = "Calculation in progress",
-                 detail = "Get values")
-    
+    line.lty <- sapply(1:8, function(x) as.numeric(input[[paste0("linelty", x)]]))
+
     # if custom polygon color get RGB from separate input panel or "none"
-    if(input$polygon == "custom") {
-      polygon.col<- adjustcolor(col = input$rgbPolygon, alpha.f = input$alpha.polygon/100)
-    } else {
-      polygon.col<- ifelse(input$polygon == "none", 
-                           input$polygon, 
-                           adjustcolor(col = input$polygon, alpha.f = input$alpha.polygon/100))
-    }
-    
+    polygon.col <- ifelse(input$polygon == "custom",
+                          adjustcolor(col = input$rgbPolygon, alpha.f = input$alpha.polygon/100),
+                          ifelse(input$polygon == "none",
+                                 input$polygon,
+                                 adjustcolor(col = input$polygon, alpha.f = input$alpha.polygon/100)))
+
     # if custom polygon color get RGB from separate input panel or "none"
     # (secondary data set)
-    if(input$polygon2 == "custom") {
-      polygon.col2<- adjustcolor(col = input$rgbPolygon2, alpha.f = input$alpha.polygon/100)
-    } else {
-      polygon.col2<- ifelse(input$polygon2 == "none", 
-                            input$polygon2, 
-                            adjustcolor(col = input$polygon2, alpha.f = input$alpha.polygon/100))
-    }
-    
-    
+    polygon.col2 <- ifelse(input$polygon2 == "custom",
+                           adjustcolor(col = input$rgbPolygon2, alpha.f = input$alpha.polygon/100),
+                           ifelse(input$polygon2 == "none",
+                                  input$polygon2,
+                                  adjustcolor(col = input$polygon2, alpha.f = input$alpha.polygon/100)))
+
+
     # if custom bar color get RGB from separate input panel or "none"
-    if(input$bar == "custom") {
-      bar.col<- adjustcolor(col = input$rgbBar, alpha.f = input$alpha.bar/100)
-    } else {
-      bar.col<- ifelse(input$bar == "none", 
-                       input$bar, 
-                       adjustcolor(col = input$bar, alpha.f = input$alpha.bar/100))
-    }
-    
+    bar.col <- ifelse(input$bar == "custom",
+                      adjustcolor(col = input$rgbBar, alpha.f = input$alpha.bar/100),
+                      ifelse(input$bar == "none",
+                             input$bar,
+                             adjustcolor(col = input$bar, alpha.f = input$alpha.bar/100)))
+
+
     # if custom bar color get RGB from separate input panel or "none"
     # SECONDARY DATA SET
-    if(input$bar2 == "custom") {
-      bar.col2<- adjustcolor(col = input$rgbBar2, alpha.f = input$alpha.bar/100)
-    } else {
-      bar.col2<- ifelse(input$bar2 == "none", 
-                        input$bar, 
-                        adjustcolor(col = input$bar2, alpha.f = input$alpha.bar/100))
-    }
-    
+    bar.col2 <- ifelse(input$bar2 == "custom",
+                       adjustcolor(col = input$rgbBar2, alpha.f = input$alpha.bar/100),
+                       ifelse(input$bar2 == "none",
+                              input$bar,
+                              adjustcolor(col = input$bar2, alpha.f = input$alpha.bar/100)))
+
     # if custom grid color get RGB from separate input panel or "none"
-    if(input$grid == "custom") {
-      grid.col<- adjustcolor(col = input$rgbGrid, alpha.f = input$alpha.grid/100)
-    } else {
-      grid.col<- ifelse(input$grid == "none",
-                        input$grid, 
-                        adjustcolor(col = input$grid, alpha.f = input$alpha.grid/100))
-    }
-    
-    # update progress bar
-    progress$set(value = 4)
-    progress$set(message = "Calculation in progress",
-                 detail = "Almost there...")
-    
-    # workaround: if no legend wanted set label to NA and hide 
+    grid.col <- ifelse(input$grid == "custom",
+                       adjustcolor(col = input$rgbGrid, alpha.f = input$alpha.grid/100),
+                       ifelse(input$grid == "none",
+                              input$grid,
+                              adjustcolor(col = input$grid, alpha.f = input$alpha.grid/100)))
+
+    # workaround: if no legend wanted set label to NA and hide
     # symbol on coordinates -999, -999
     if(input$showlegend == FALSE) {
       legend<- c(NA,NA)
@@ -388,7 +313,7 @@ function(input, output, session) {
         legend.pos<- input$legend.pos
       }
     }
-    
+
     # TODO: arg 'bar' handling (custom values, 1 or 2 bars)
     if (input$customSigBar) {
       if (!input$addBar)
@@ -399,42 +324,31 @@ function(input, output, session) {
       bar <- TRUE
     }
 
-    
-    # check wether a keyword or a numeric value is used for
+
+    # check whether a keyword or a numeric value is used for
     # centrality
-    if(input$centrality == "custom") {
-        centrality<- input$centralityNumeric
-    } else {
-      centrality<- input$centrality
-    }
-    
-    # check wether predefined or custom dispersion
+    centrality <- ifelse(input$centrality == "custom", input$centralityNumeric, input$centrality)
+
+    # check whether predefined or custom dispersion
     dispersion<- ifelse(input$dispersion == "custom", paste("p", input$cinn, sep=""), input$dispersion)
-    
-    # validate(need()) makes sure that all data are available to
-    # renderUI({}) before plotting and will wait until there
-    validate(need(expr = input$bw, message = ''),
-             need(expr = input$zlim, message = ''),
-             need(expr = input$ylim, message = ''),
-             need(expr = input$centralityNumeric, message = 'Waiting for data... Please wait!'))
-    
+
     # save all arguments in a list
-    args<- list(data = data,
+    values$args<- list(data = values$data,
                 y.axis = input$yaxis,
                 bw = input$bw,
                 bar = bar,
                 dispersion = dispersion,
                 plot.ratio = input$p.ratio,
-                z.0 = centrality, 
-                log.z = input$logz, 
-                summary = summary,
+                z.0 = centrality,
+                log.z = input$logz,
+                summary = if (input$summary) input$stats else NA,
                 summary.pos = input$sumpos,
                 summary.method = input$summary.method,
                 col = c(color,color2),
                 pch = c(pch,pch2),
                 zlab = input$zlab,
                 main = input$main,
-                zlim = input$zlim, 
+                zlim = input$zlim,
                 cex = input$cex,
                 mtext = input$mtext,
                 stats = input$statlabels,
@@ -463,107 +377,41 @@ function(input, output, session) {
                 hist = input$histogram,
                 dots = input$dots,
                 frame = input$frame)
-    
-    progress$set(value = 5)
-    progress$set(message = "Calculation in progress",
-                 detail = "Ready to plot")
+  })
+
+  # render Abanico Plot
+  output$main_plot <- renderPlot({
+
+    # validate(need()) makes sure that all data are available to
+    # renderUI({}) before plotting and will wait until there
+    validate(need(expr = input$bw, message = ''),
+             need(expr = input$zlim, message = ''),
+             need(expr = input$ylim, message = ''),
+             need(expr = input$centralityNumeric, message = 'Waiting for data... Please wait!'))
+
+    # plot Abanico Plot
+    do.call(what = plot_AbanicoPlot, args = values$args)
 
-    # plot Abanico Plot 
-    do.call(what = plot_AbanicoPlot, args = args)
-    
-    # prepare code as text output
-    str1 <- "data <- data.table::fread(file, data.table = FALSE)"
-    
-    if(!all(is.na(unlist(values$data_secondary)))) {
-      str2 <- "file2 <- file.choose()"
-      str3 <- "data2 <- data.table::fread(file2, data.table = FALSE)"
-      str4 <- "data <- list(data, data2)"
-      str1 <- paste(str1, str2, str3, str4, sep = "\n")
-    }
-    
-    header <- paste("# To reproduce the plot in your local R environment",
-                  "# copy and run the following code to your R console.",
-                  "library(Luminescence)",
-                  "file <- file.choose()",
-                  str1,
-                  "\n",
-                  sep = "\n")
-    
-    names <- names(args)
-    
-    verb.arg <- paste(mapply(function(name, arg) {
-      if (all(inherits(arg, "character")))
-        arg <- paste0("'", arg, "'")
-      if (length(arg) > 1)
-        arg <- paste0("c(", paste(arg, collapse = ", "), ")")
-      if (is.null(arg))
-        arg <- "NULL"
-      paste(name, "=", arg) 
-    }, names[-1], args[-1]), collapse = ",\n")
-    
-    funCall <- paste0("plot_AbanicoPlot(data = data,\n", verb.arg, ")")
-    
-    code.output <- paste0(header, funCall, collapse = "\n")
-    
-    # nested renderText({}) for code output on "R plot code" tab
-    output$plotCode<- renderText({
-      
-      code.output
-      
-    })##EndOf::renderText({})
-    
-    
-    output$exportScript <- downloadHandler(
-      filename = function() { paste(input$filename, ".", "R", sep="") },
-      content = function(file) {
-        write(code.output, file)
-      },#EO content =,
-      contentType = "text"
-    )#EndOf::dowmloadHandler()
-    
-    
-    # nested downloadHandler() to print plot to file
-    output$exportFile <- downloadHandler(
-      filename = function() { paste(input$filename, ".", input$fileformat, sep="") },
-      content = function(file) {
-        
-        # determine desired fileformat and set arguments
-        if(input$fileformat == "pdf") {
-          pdf(file, 
-              width = input$imgwidth, 
-              height = input$imgheight, 
-              paper = "special",
-              useDingbats = FALSE, 
-              family = input$fontfamily)
-        }
-        if(input$fileformat == "svg") {
-          svg(file, 
-              width = input$imgwidth, 
-              height = input$imgheight, 
-              family = input$fontfamily)
-        }
-        if(input$fileformat == "eps") {
-          postscript(file, 
-                     width = input$imgwidth, 
-                     height = input$imgheight, 
-                     paper = "special", 
-                     family = input$fontfamily)
-        }
-        
-        # plot Abanico Plot 
-        do.call(what = plot_AbanicoPlot, args = args)
-        
-        dev.off()
-      },#EO content =,
-      contentType = "image"
-    )#EndOf::dowmloadHandler()
   })##EndOf::renderPlot({})
-  
-  
+
+  observe({
+    # nested renderText({}) for code output on "R plot code" tab
+    code.output <- callModule(RLumShiny:::printCode, "printCode",
+                              n_input = ifelse(!all(is.na(unlist(values$data_secondary))), 2, 1),
+                              fun = "plot_AbanicoPlot(data,", args = values$args)
+
+    output$plotCode<- renderText({
+      code.output
+    })##EndOf::renderText({})
+
+    callModule(RLumShiny:::exportCodeHandler, "export", code = code.output)
+    callModule(RLumShiny:::exportPlotHandler, "export", fun = "plot_AbanicoPlot", args = values$args)
+  })
+
   Selected<- reactive({
     input$refresh
   })
-  
+
   # renderTable() that prints the data to the second tab
   output$dataset<- renderDataTable(
     options = list(pageLength = 10, autoWidth = FALSE),
@@ -571,16 +419,16 @@ function(input, output, session) {
       table.on('click.dt', 'tr', function() {
         $(this).toggleClass('selected');
         Shiny.onInputChange('rows',
-                            table.rows('.selected').data().toArray());
+                            table.rows('.selected').values$data.toArray());
       });
     }",
 {
-  data <- Data()
+  data <- values$data
   colnames(data[[1]])<- c("De","De error")
   data[[1]]
-  
+
 })##EndOf::renterTable()
-  
+
   # renderTable() that prints the secondary data to the second tab
   output$dataset2<- renderDataTable(
     options = list(pageLength = 10, autoWidth = FALSE),
@@ -588,23 +436,23 @@ function(input, output, session) {
       table.on('click.dt', 'tr', function() {
         $(this).toggleClass('selected');
         Shiny.onInputChange('rows',
-                            table.rows('.selected').data().toArray());
+                            table.rows('.selected').values$data.toArray());
       });
     }",
 {
   if(!all(is.na(unlist(values$data_secondary)))) {
-    data <- Data()
+    data <- values$data
     colnames(data[[2]])<- c("De","De error")
     data[[2]]
-  } 
+  }
 })##EndOf::renterTable()
-  
+
   # renderTable() to print the results of the
   # central age model (CAM)
   output$CAM<- renderDataTable(
     options = list(pageLength = 10, autoWidth = FALSE),
     {
-      data<- Data()
+      data<- values$data
       t<- as.data.frame(matrix(nrow = length(data), ncol = 7))
       colnames(t)<- c("Data set","n", "log data", "Central dose", "SE abs.", "OD (%)", "OD error (%)")
       res<- lapply(data, function(x) { calc_CentralDose(x, verbose = FALSE, plot = FALSE) })
@@ -616,5 +464,5 @@ function(input, output, session) {
       }
       t
     })##EndOf::renterTable()
-  
-}##EndOf::shinyServer(function(input, output)
\ No newline at end of file
+
+}##EndOf::shinyServer(function(input, output)
